from setuptools import setup

setup(name='uduak_distributions',
      version='0.3',
      description='Gaussian_distributions',
      packages=['uduak_distributions'],
      author= "uduak umanah",
      author_email = "uduakumanah10@gmail.com",
      zip_safe=False)
